==> resin-4.0.27-src.tar.gz: resin-4.0.27/modules/resin/src/com/caucho/boot/DeployListCommand.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Alex Rojkov
 */

package com.caucho.boot;

import com.caucho.server.admin.TagResult;
import com.caucho.server.admin.WebAppDeployClient;
import com.caucho.util.L10N;

public class DeployListCommand extends AbstractRepositoryCommand
{
  private static final L10N L = new L10N(DeployListCommand.class);
  
  @Override
  public String getDescription()
  {
    return "lists deployed applications";
  }
  
  @Override
  public int doCommand(WatchdogArgs args,
                       WatchdogClient client,
                       WebAppDeployClient deployClient)
  {
    String pattern = args.getDefaultArg();
    if (pattern == null)
      pattern = ".*";

    TagResult[] tags = deployClient.queryTags(pattern);

    for (TagResult tag : tags) {
      System.out.println(tag.getTag());
    }

    return 0;
  }

  @Override
  public String getUsageArgs()
  {
    return " [<pattern>]";
  }

  @Override
  public boolean isDefaultArgsAccepted()
  {
    return true;
  }
}

==> resin-4.0.65-src.tar.gz: resin-4.0.65/modules/resin/src/com/caucho/boot/DeployListCommand.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Alex Rojkov
 */

package com.caucho.boot;

import com.caucho.server.admin.WebAppDeployClient;
import com.caucho.server.deploy.DeployTagResult;
import com.caucho.util.L10N;

public class DeployListCommand extends AbstractRepositoryCommand
{
  private static final L10N L = new L10N(DeployListCommand.class);
  
  @Override
  public String getDescription()
  {
    return "lists deployed applications";
  }
  
  @Override
  public int doCommand(WatchdogArgs args,
                       WatchdogClient client,
                       WebAppDeployClient deployClient)
  {
    String pattern = args.getDefaultArg();
    if (pattern == null)
      pattern = ".*";

    DeployTagResult[] tags = deployClient.queryTags(pattern);

    for (DeployTagResult tag : tags) {
      System.out.println(tag.getTag());
    }

    return 0;
  }

  @Override
  public String getUsageArgs()
  {
    return " [<pattern>]";
  }

  @Override
  public boolean isDefaultArgsAccepted()
  {
    return true;
  }
}
